==> qtify_0.0.1-1.tar.gz: qtify-0.0.1/mainwindow.cpp <==
#include <QDebug>
#include <list>

#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "despotifycallback.h"

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);

    /* Initialize despotify */
    this->dw = new DespotifyWrap();
    qDebug() << "Is spotify initialized? " << this->dw->IsInitialized();

    /* Connect signals */
    this->connect(this->dw, SIGNAL(PlaylistsUpdated()),this, SLOT(PlaylistsUpdated()));
    this->connect(&dc, SIGNAL(NewTrack(int,int,int,track*)),this, SLOT(NewTrack(int,int,int,track*)));
    this->connect(&dc, SIGNAL(TellTime(int,int,int)),this, SLOT(TellTime(int,int,int)));
}

MainWindow::~MainWindow()
{
    delete ui;
    this->dw->Exit();
}

void MainWindow::changeEvent(QEvent *e)
{
    QMainWindow::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

void MainWindow::on_pushButton_5_clicked()
{

}

void MainWindow::on_pbLogin_clicked()
{
    /* Convert lineedit text to char* */
    QByteArray user = this->ui->leLogin->text().toLatin1();
    char *c_user = user.data();
    QByteArray pass = this->ui->lePassword->text().toLatin1();
    char *c_pass = pass.data();

    /* Try to authenticate */
    if(!this->dw->Authenticate(c_user,c_pass)) {
        this->ui->lblLoginError->setText(QString("Incorrect credentials entered\nplease try again."));
    } else {
        this->ui->lblLoginError->setText(QString(" "));

        /* Show inside widget */
        this->ui->swWidgets->setCurrentWidget(this->ui->pgInside);

        /* Update playlists */
        this->dw->UpdatePlaylists();
    }
}

void MainWindow::PlaylistsUpdated() {

    qDebug() << "Received signal: PlaylistsUpdated";

    /* Clear list */
    this->ui->cbPlaylists->clear();

    /* Insert all playlists in combo box */
    for (playlist* p = this->dw->GetPlaylists(); p; p = p->next)
    {
        this->ui->cbPlaylists->addItem(QString(p->name),QString((char*)p->playlist_id));
    }
}

void MainWindow::PrintTracks() {

    this->ui->twSongs->clear();

    track* head = this->dw->lastlist->tracks;
    int count=0;
    for (track* t = head; t; t = t->next) {
        if (t->has_meta_data) {
            //wrapper_wprintf(L"%3d: %-40s %2d:%02d ", count++, t->title,t->length / 60000, t->length % 60000 / 1000);
            QString t_artist = QString("");

            for (struct artist* a = t->artist; a; a = a->next)
                t_artist += a->name;
            t_artist = t_artist.toLatin1();
            QString t_song = QString(t->title).toLatin1();
            QString t_length = QString().setNum((int)(t->length / 60000)) + QString(":") + QString().setNum((int)(t->length % 60000 / 1000));
            QString t_album = QString(t->album).toLatin1();
            QString t_popularity = QString().setNum(t->popularity);

            /* Check if song is playable */
            if(t->playable) {

                QTreeWidgetItem *t_item = new QTreeWidgetItem(this->ui->twSongs);
                t_item->setText(0, QString("").setNum(count));
                t_item->setText(1, t_song);
                t_item->setText(2, t_artist);
                t_item->setText(3, t_album);
                t_item->setText(4, t_length);
                t_item->setText(5, t_popularity);
            }
        }
        count++;
    }
}

void MainWindow::on_cbPlaylists_currentIndexChanged(int index)
{
    qDebug() << "Deprecated shit";
}


void MainWindow::on_cbPlaylists_activated(int index)
{
    qDebug() << "Deprecated shit 2";
}

void MainWindow::on_pbShowPlaylist_clicked()
{
    qDebug() << "Show playlist button clicked";
    /* Iterate through all playlists */
    for (playlist* p = this->dw->GetPlaylists(); p; p = p->next)
    {
        /* ToDo : Use ID */
        if(QString((char*)p->name) == this->ui->cbPlaylists->currentText()) {
            qDebug() << "Print tracks";
            this->dw->lastlist = p;
            this->PrintTracks();
        }
    }
}

void MainWindow::on_twSongs_itemDoubleClicked(QTreeWidgetItem* item, int column)
{
    qDebug() << "Playing offset " << QString(item->text(0));
    this->dw->Play(QString(item->text(0)).toInt());
}

void MainWindow::on_pbSearch_clicked()
{
    QByteArray search = this->ui->leSearch->text().toLatin1();
    char *c_search = search.data();

    if(this->dw->Search(c_search))
        this->PrintTracks();
}

void MainWindow::on_pushButton_4_clicked()
{
    this->dw->PlayPrev();
}

void MainWindow::on_pushButton_3_clicked()
{
    this->dw->PlayNext();
}
void MainWindow::on_pushButton_2_clicked()
{

}

void MainWindow::on_pushButton_clicked()
{
    this->dw->player->PlayPause();
}

void MainWindow::NewTrack(int min, int sec, int totsec, track *t) {

    this->song_tot_len=totsec;
    this->ui->hsElapsed->setMaximum(totsec);

}

void MainWindow::TellTime(int min, int sec, int totsec) {

    int t_min = (int)this->song_tot_len/60;
    int t_sec = (int)this->song_tot_len%60;

    QString elapse;
    elapse = QString().setNum(min) + QString(":") + QString().setNum(sec) + QString(" / ") + QString().setNum(t_min) + QString(":") + QString().setNum(t_sec);

    this->ui->lblElapsed->setText(elapse);
    this->ui->hsElapsed->setValue(totsec);

}

==> qtify_0.0.1-3.tar.gz: qtify-0.0.1/mainwindow.cpp <==
#include <QDebug>
#include <list>

#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "despotifycallback.h"

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);

    /* Initialize despotify */
    this->dw = new DespotifyWrap();
    qDebug() << "Is spotify initialized? " << this->dw->IsInitialized();

    /* Connect signals */
    this->connect(this->dw, SIGNAL(PlaylistsUpdated()),this, SLOT(PlaylistsUpdated()));
    this->connect(&dc, SIGNAL(NewTrack(int,int,int,track*)),this, SLOT(NewTrack(int,int,int,track*)));
    this->connect(&dc, SIGNAL(TellTime(int,int,int)),this, SLOT(TellTime(int,int,int)));

    this->connect(this->dw->player, SIGNAL(Playing()),this, SLOT(Playing()));
    this->connect(this->dw->player, SIGNAL(Paused()),this, SLOT(Paused()));
    this->connect(this->dw->player, SIGNAL(Exiting()),this, SLOT(Exiting()));

    this->ui->twSongs->setColumnWidth(0,60);
    this->ui->twSongs->setColumnWidth(1,250);
    this->ui->twSongs->setColumnWidth(2,150);
    this->ui->twSongs->setColumnWidth(3,150);
    this->ui->twSongs->setColumnWidth(4,70);
    this->ui->twSongs->setColumnWidth(5,70);

    this->ui->twSongs->sortByColumn(0,Qt::AscendingOrder);

}

MainWindow::~MainWindow()
{
    delete ui;
    this->dw->Exit();
}

void MainWindow::changeEvent(QEvent *e)
{
    QMainWindow::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

void MainWindow::on_pushButton_5_clicked()
{

}

void MainWindow::on_pbLogin_clicked()
{
    /* Convert lineedit text to char* */
    QByteArray user = this->ui->leLogin->text().toLatin1();
    char *c_user = user.data();
    QByteArray pass = this->ui->lePassword->text().toLatin1();
    char *c_pass = pass.data();

    /* Try to authenticate */
    if(!this->dw->Authenticate(c_user,c_pass)) {
        this->ui->lblLoginError->setText(tr("Incorrect credentials entered\nplease try again."));
    } else {
        this->ui->lblLoginError->setText(QString(""));

        /* Show inside widget */
        this->ui->swWidgets->setCurrentWidget(this->ui->pgInside);

        /* Update playlists */
        this->dw->UpdatePlaylists();
    }
}

void MainWindow::PlaylistsUpdated() {

    qDebug() << "Received signal: PlaylistsUpdated";

    /* Clear list */
    this->ui->cbPlaylists->clear();

    /* Insert all playlists in combo box */
    playlist* p = this->dw->GetPlaylists();
    if(p!=NULL){
        for (p; p; p = p->next)
        {
            if(p != NULL) {
                this->ui->cbPlaylists->addItem(QString(p->name),QString((char*)p->playlist_id));
            } else {
                qDebug() << "This really shouldn't happen... really...";
            }
        }
    }
}

void MainWindow::PrintTracks() {

    this->ui->twSongs->clear();

    track* head = this->dw->lastlist->tracks;
    int count=0;
    for (track* t = head; t; t = t->next) {
        if (t->has_meta_data) {
            //wrapper_wprintf(L"%3d: %-40s %2d:%02d ", count++, t->title,t->length / 60000, t->length % 60000 / 1000);
            QString t_artist = QString("");

            for (struct artist* a = t->artist; a; a = a->next)
                t_artist += a->name;
            t_artist = t_artist.toLatin1();

            QString t_song = QString(t->title).toLatin1();
            QString t_length = QString("%1:%2").arg((int)(t->length / 60000),2,10,QChar('0')).arg((int)(t->length % 60000 / 1000),2,10,QChar('0'));
            QString t_album = QString(t->album).fromUtf8(t->album);
            QString t_popularity = QString().setNum(t->popularity);

            /* Check if song is playable */
            if(t->playable) {

                QTreeWidgetItem *t_item = new QTreeWidgetItem(this->ui->twSongs);
                t_item->setText(0, QString("%1").arg(count,3,10,QChar(' ')));
                t_item->setText(1, t_song);
                t_item->setText(2, t_artist);
                t_item->setText(3, t_album);
                t_item->setText(4, t_length);
                int icon=(int)(t->popularity*10/2);
                if(icon>0&&icon<6) {
                    t_item->setIcon(5, QPixmap(QString(":/gfx/res/rating_%1.png").arg(icon)));
                    /*t_item->setText(5, QString().setNum(t_popularity,));
                    t_item->setForeground(5,t_item->backgroundColor(5));*/
                }
            }
        }
        count++;
    }
}

void MainWindow::on_pbShowPlaylist_clicked()
{
    qDebug() << "Show playlist button clicked";
    /* Iterate through all playlists */
    for (playlist* p = this->dw->GetPlaylists(); p; p = p->next)
    {
        /* ToDo : Use ID */
        if(QString((char*)p->name) == this->ui->cbPlaylists->currentText()) {
            qDebug() << "Print tracks";
            this->dw->lastlist = p;
            this->PrintTracks();
        }
    }
}

void MainWindow::on_twSongs_itemDoubleClicked(QTreeWidgetItem* item, int column)
{
    qDebug() << "Playing offset " << QString(item->text(0));
    this->dw->Play(QString(item->text(0)).toInt());
}

void MainWindow::on_pbSearch_clicked()
{
    QByteArray search = this->ui->leSearch->text().toLatin1();
    char *c_search = search.data();

    if(this->dw->Search(c_search))
        this->PrintTracks();
}

void MainWindow::on_pushButton_4_clicked()
{
    this->dw->PlayPrev();
}

void MainWindow::on_pushButton_3_clicked()
{
    this->dw->PlayNext();
}

void MainWindow::on_pushButton_2_clicked()
{

}

void MainWindow::on_pushButton_clicked()
{
    this->dw->player->PlayPause();
}

void MainWindow::NewTrack(int min, int sec, int totsec, track *t) {

    this->song_tot_len=totsec;
    this->ui->hsElapsed->setMaximum(totsec);

}

void MainWindow::TellTime(int min, int sec, int totsec) {

    int t_min = (int)this->song_tot_len/60;
    int t_sec = (int)this->song_tot_len%60;

    QString elapse;
    elapse = QString("%1:%2 / %3:%4").arg(min,2,10,QChar('0')).arg(sec,2,10,QChar('0')).arg(t_min,2,10,QChar('0')).arg(t_sec,2,10,QChar('0'));

    this->ui->lblElapsed->setText(elapse);
    this->ui->hsElapsed->setValue(totsec);

}

void MainWindow::Playing() {
    qDebug() << "Playing";
}

void MainWindow::Paused() {
    qDebug() << "Paused";
}

void MainWindow::Exiting() {
    qDebug() << "Exiting";
}

void MainWindow::on_cbPlaylists_activated(int index)
{

}

void MainWindow::on_cbPlaylists_currentIndexChanged(QString )
{

}

void MainWindow::on_cbPlaylists_currentIndexChanged(int index)
{

}
